@@ -760,7 +760,7 @@ and call `auth-source-forget+'."
 Required %s token (%S for %S) does not exist.
 See https://magit.vc/manual/ghub/Getting-Started.html
 or (info \"(ghub)Getting Started\") for instructions.
-(The setup wizard no longer exists.)"
+\(The setup wizard no longer exists.)"
                             (capitalize (symbol-name (or forge 'github)))
                             user host))))))
     (if (functionp token) (funcall token) token)))
